from nmec import NMEC
test = NMEC()
print(test.example())